@@ -6,9 +6,10 @@ from tabulate import tabulate
 import io
 import re as regex
 from base64 import b64encode
+from datetime import date
 
 def _download_html(html, filename="tearsheet.html"):
-    jscode = _regex.sub(' +', ' ', """<script>
+    jscode = regex.sub(' +', ' ', """<script>
     var bl=new Blob(['{{html}}'],{type:"text/html"});
     var a=document.createElement("a");
     a.href=URL.createObjectURL(bl);
@@ -23,8 +24,8 @@ def _file_stream():
     """Returns a file stream"""
     return io.BytesIO()
   
-def _html_table(obj, showindex="default"):
-    obj = tabulate(obj.T, headers="keys", tablefmt='html',
+def _html_table(obj, showindex=True, headers="keys"):
+    obj = tabulate(obj.T, headers=headers, tablefmt='html',
                     floatfmt=".2f", showindex=showindex)
     obj = obj.replace(' style="text-align: right;"', '')
     obj = obj.replace(' style="text-align: left;"', '')
@@ -33,7 +34,7 @@ def _html_table(obj, showindex="default"):
     obj = regex.sub(' +</td>', '</td>', obj)
     obj = regex.sub('<th> +', '<th>', obj)
     obj = regex.sub(' +</th>', '</th>', obj)
-    return 
+    return obj
 
 def _embed_figure(figfile, figfmt):
     figbytes = figfile.getvalue()
@@ -58,8 +59,8 @@ def report(returns, benchmark, rf,
         tpl = f.read()
         f.close()
 
-    date_range = returns.index.strftime('%e %b, %Y')
-    tpl = tpl.replace('{{date_range}}', date_range[0] + ' - ' + date_range[-1])
+    date_now = date.today().strftime('%e %b, %Y')
+    tpl = tpl.replace('{{date}}', date_now)
     tpl = tpl.replace('{{title}}', title)
     tpl = tpl.replace('{{firm}}', firm)
     tpl = tpl.replace('{{v}}', version)
@@ -68,28 +69,28 @@ def report(returns, benchmark, rf,
                           display=False,
                           periods=periods)
 
-    tpl = tpl.replace('{{info}}', _html_table(mtrx[0]))
+    tpl = tpl.replace('{{info}}', _html_table(mtrx[0],headers=['Analysis info']))
     tpl = tpl.replace('{{returns}}', _html_table(mtrx[1]))
     tpl = tpl.replace('{{performance}}', _html_table(mtrx[2]))
     tpl = tpl.replace('{{risk}}', _html_table(mtrx[3]))
-    tpl = tpl.replace('{{pnl}}', _html_table(mtrx)[4])
+    tpl = tpl.replace('{{pnl}}', _html_table(mtrx[4]))
 
     tpl = tpl.replace('<tr><td></td><td></td><td></td></tr>',
                       '<tr><td colspan="3"><hr></td></tr>')
     tpl = tpl.replace('<tr><td></td><td></td></tr>',
                       '<tr><td colspan="2"><hr></td></tr>')
 
-    # dd = _stats.to_drawdown_series(returns)
-    # dd_info = _stats.drawdown_details(dd).sort_values(
-    #     by='max drawdown', ascending=True)[:10]
-    # dd_info = dd_info[['start', 'end', 'max drawdown', 'days']]
-    # dd_info.columns = ['Started', 'Recovered', 'Drawdown', 'Days']
-    # tpl = tpl.replace('{{dd_info}}', _html_table(dd_info, False))
+           
+    dd_info = mtrx[5][mtrx[5].columns.get_level_values(0).unique()[0]]
+    dd_info = dd_info.sort_values(
+        by='max drawdown', ascending=True)[:10]
+    dd_info = dd_info[['start', 'valley', 'end', 'max drawdown', 'days']]
+    dd_info.columns = ['Started', 'Valley','Recovered', 'Drawdown', 'Days']
+    tpl = tpl.replace('{{dd_info}}', _html_table(dd_info.T, showindex=False))
 
-    # plots
-    figs = report_plots(returnsiloc[:,0], benchmarkiloc[:,0], rf, grayscale=grayscale, periods=periods, display=False, save=True)
+    figs = report_plots(returns.iloc[:,0], benchmark.iloc[:,0], rf, grayscale=grayscale, periods=periods, display=False, save=True)
 
-    tpl = tpl.replace('{{returns}}', figs[0])
+    tpl = tpl.replace('{{cum_returns}}', figs[0])
     tpl = tpl.replace('{{log_returns}}', figs[1])
     tpl = tpl.replace('{{vol_returns}}', figs[2])
     tpl = tpl.replace('{{eoy_returns}}', figs[3])
@@ -104,7 +105,7 @@ def report(returns, benchmark, rf,
     tpl = tpl.replace('{{monthly_heatmap}}', figs[12])
     tpl = tpl.replace('{{returns_dist}}', figs[13])
 
-    tpl = _regex.sub(r'\{\{(.*?)\}\}', '', tpl)
+    tpl = regex.sub(r'\{\{(.*?)\}\}', '', tpl)
     tpl = tpl.replace('white-space:pre;', '')
 
     if output is None:
@@ -127,6 +128,8 @@ def report_metrics(dr, bench, rf, periods=252, display=True):
   dsp_info = pd.DataFrame()
   date_start = dr.index.strftime('%Y-%m-%d')[0]
   date_end = dr.index.strftime('%Y-%m-%d')[-1]
+  dsp_info['Strategy'] = pd.Series(dr.columns[0])
+  dsp_info['Benchmark'] = pd.Series(bench.columns[0])
   dsp_info['Start Period'] = pd.Series(date_start)
   dsp_info['End Period'] = pd.Series(date_end)
   dsp_info['Working days'] = pd.Series(len(dr.index)) 
@@ -300,15 +303,16 @@ def report_metrics(dr, bench, rf, periods=252, display=True):
   return dsp_info, dsp_returns, dsp_performance, dsp_risk, dsp_pnl, dd_details
 
 def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), periods=252, display=True, figfmt='svg', save=False):
-  rfd=rf['dR']
-  rfy=rf['yR']
-  
+  rfd = rf['dR'].rename('DI')
+  rfy = rf['yR'].rename('DI')
+  ra = returns.iloc[:,0]
   figs = []
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
   plots.plt_returns(returns, benchmark, rfd,
               grayscale=grayscale,
               figsize=(figsize[0], figsize[0]*.6),
               show=display,
+              savefig=savefig,
               ylabel=False)
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
 
@@ -331,7 +335,7 @@ def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), period
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
   
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
-  plots.plt_yearly_returns(returns, benchmark, rfd,
+  plots.plt_yearly_returns(ra, benchmark, rfd,
               grayscale=grayscale,
               figsize=(figsize[0], figsize[0]*.5),
               show=display,
@@ -340,7 +344,7 @@ def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), period
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
 
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
-  plots.plt_histogram(returns,
+  plots.plt_histogram(ra,
                 grayscale=grayscale,
                 figsize=(figsize[0], figsize[0]*.5),
                 show=display,
@@ -349,7 +353,7 @@ def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), period
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
 
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
-  plots.plt_daily_returns(returns,
+  plots.plt_daily_returns(ra,
                     grayscale=grayscale,
                     figsize=(figsize[0], figsize[0]*.3),
                     show=display,
@@ -358,7 +362,7 @@ def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), period
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
 
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
-  plots.plt_rolling_beta(returns, benchmark,
+  plots.plt_rolling_beta(ra, benchmark,
                    grayscale=grayscale,
                    window1=int(periods/2),
                    window2=periods,
@@ -369,7 +373,7 @@ def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), period
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
   
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
-  plots.plt_rolling_volatility(returns, benchmark,
+  plots.plt_rolling_volatility(ra, benchmark,
                          grayscale=grayscale,
                          figsize=(figsize[0], figsize[0]*.3),
                          show=display,
@@ -379,7 +383,7 @@ def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), period
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
 
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
-  plots.plt_rolling_sharpe(returns, benchmark, rfy,
+  plots.plt_rolling_sharpe(ra, benchmark, rfy,
                      grayscale=grayscale,
                      figsize=(figsize[0], figsize[0]*.3),
                      show=display,
@@ -389,7 +393,7 @@ def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), period
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
   
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
-  plots.plt_rolling_sortino(returns, benchmark, rfy,
+  plots.plt_rolling_sortino(ra, benchmark, rfy,
                       grayscale=grayscale,
                       figsize=(figsize[0], figsize[0]*.3),
                       show=display,
@@ -399,7 +403,7 @@ def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), period
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
 
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
-  plots.plt_drawdowns_periods(returns, periods=5,
+  plots.plt_drawdowns_periods(ra, periods=5,
                         grayscale=grayscale,
                         figsize=(figsize[0], figsize[0]*.5),
                         show=display,
@@ -408,7 +412,7 @@ def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), period
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
 
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
-  plots.plt_drawdown(returns,
+  plots.plt_drawdown(ra,
                grayscale=grayscale,
                figsize=(figsize[0], figsize[0]*.4),
                show=display,
@@ -417,7 +421,7 @@ def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), period
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
 
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
-  plots.plt_monthly_heatmap(returns,
+  plots.plt_monthly_heatmap(ra,
                       grayscale=grayscale,
                       figsize=(figsize[0], figsize[0]*.5),
                       show=display,
@@ -426,7 +430,7 @@ def report_plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), period
   figs.append(_embed_figure(savefig['fname'], savefig['format'])) if save else None
 
   savefig = {'fname': _file_stream(), 'format': figfmt} if save else None
-  plots.plt_distribution(returns,
+  plots.plt_distribution(ra,
                    grayscale=grayscale,
                    figsize=(figsize[0], figsize[0]*.5),
                    show=display,
